pub enum EventHubTokenCredential {
    SharedAccessCredential(SharedAccessCredential),
    Other(Box<dyn TokenCredential>),
}
Provides a generic token-based credential for a given Event Hub instance.

This supports SharedAccessCredential and any other credential type that implements TokenCredential, eg. [azure_identity::DefaultAzureCredential].

Example

use azure_identity::DefaultAzureCredential;
use azeventhubs::authorization::EventHubTokenCredential;

let credential = EventHubTokenCredential::from(DefaultAzureCredential::default());

Variants



SharedAccessCredential(SharedAccessCredential)

Shared Access Signature credential.



Other(Box<dyn TokenCredential>)

Other credential types.

Implementations

source

impl EventHubTokenCredential

source

pub fn new(source: impl Into<Self>) -> Self

Creates a new instance of EventHubTokenCredential. This is simply an alias for From::from

source

pub fn is_shared_access_credential(&self) -> bool

Indicates whether the credential is based on an Event Hubs shared access policy.