EventHubsRetryMode

Enum EventHubsRetryMode 

pub enum EventHubsRetryMode {
    Fixed,
    Exponential,
}
The type of approach to apply when calculating the delay between retry attempts.

Variants



Fixed

Retry attempts happen at fixed intervals; each delay is a consistent duration



Exponential

Retry attempts will delay based on a back-off strategy, where each attempt will increase the duration that it waits before retrying