pub struct PartitionReceiverOptions {
    pub connection_options: EventHubConnectionOptions,
    pub retry_options: EventHubsRetryOptions,
    pub maximum_receive_wait_time: Duration,
    pub prefetch_count: u32,
    pub identifier: Option<String>,
    pub owner_level: Option<i64>,
    pub track_last_enqueued_event_properties: bool,
}
The set of options that can be specified when creating a crate::primitives::PartitionReceiver

Fields

connection_options: EventHubConnectionOptions

The set of options that can be specified when creating an crate::EventHubConnection

retry_options: EventHubsRetryOptions

The set of options to govern retry behavior and try timeouts.

maximum_receive_wait_time: Duration

The amount of time to wait for messages when reading

prefetch_count: u32

The number of events that will be eagerly requested from the Event Hubs service and queued locally without regard to whether a read operation is currently active, intended to help maximize throughput by allowing events to be read from from a local cache rather than waiting on a service request.

identifier: Option<String>

The identifier of the receiver. If not specified, a UUID will be used.

owner_level: Option<i64>

When populated, the owner level indicates that a reading is intended to be performed exclusively for events in the requested partition and for the associated consumer group. To do so, reading will attempt to assert ownership over the partition; in the case where more than one exclusive reader attempts to assert ownership for the same partition/consumer group pair, the one having a larger value will “win.”

When an exclusive reader is used, other readers which are non-exclusive or which have a lower owner level will either not be allowed to be created, if they already exist, will encounter an exception during the next attempted operation.

track_last_enqueued_event_properties: bool

Indicates whether or not the reader should request information on the last enqueued event on the partition associated with a given event, and track that information as events are read.