pub struct CreateBatchOptions {
pub max_size_in_bytes: Option<u64>,
pub partition_key: Option<String>,
}Expand description
A set of options that can be specified when creating a batch of events.
Fields
max_size_in_bytes: Option<u64>The maximum size of the batch in bytes. If not specified, the maximum size will be determined by the Event Hub.
partition_key: Option<String>The partition key to associate with the batch of events. See `crate::producer::Partition::Key for more details.
Implementations
Sourceimpl CreateBatchOptions
impl CreateBatchOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new instance of CreateBatchOptions with default values
Default Value
max_size_in_bytes:Nonepartition_key:None
Sourcepub fn with_max_size_in_bytes(self, max_size_in_bytes: u64) -> Self
pub fn with_max_size_in_bytes(self, max_size_in_bytes: u64) -> Self
Set the max_size_in_bytes field
Sourcepub fn with_partition_key(self, partition_key: impl Into<String>) -> Self
pub fn with_partition_key(self, partition_key: impl Into<String>) -> Self
Set the partition_key field