Struct azeventhubs::EventData

source ·
pub struct EventData { /* private fields */ }
An Event Hubs event, encapsulating a set of data and its associated metadata.

Implementations

source

impl EventData

source

pub fn new(body: impl Into<Vec<u8>>) -> Self

Creates a new event from the given data

source

pub fn body(&self) -> &[u8]

The data associated with the event

source

pub fn set_body(&mut self, body: impl Into<Vec<u8>>)

Sets the body associated with the event

source

pub fn content_type(&self) -> Option<&str>

The content type associated with the event

source

pub fn set_content_type(&mut self, content_type: impl Into<Option<String>>)

Sets the content type associated with the event

source

pub fn message_id(&self) -> Option<Cow<'_, str>>

An application-defined value that uniquely identifies the event. The identifier is a free-form value and can reflect a GUID or an identifier derived from the application context.

source

pub fn set_message_id( &mut self, message_id: impl Into<String> ) -> Result<(), SetMessageIdError>

Sets the message ID associated with the event

source

pub fn correlation_id(&self) -> Option<Cow<'_, str>>

An application-defined value that represents the context to use for correlation across one or more operations. The identifier is a free-form value and may reflect a unique identity or a shared data element with significance to the application.

source

pub fn set_correlation_id(&mut self, correlation_id: impl Into<Option<String>>)

Sets the correlation ID associated with the event

source

pub fn properties(&self) -> Option<&OrderedMap<String, SimpleValue>>

The set of free-form properties which may be used for associating metadata with the event that is meaningful within the application context.