pub struct EventHubsConnectionStringProperties<'a> { /* private fields */ }Expand description
The set of properties that comprise a Event Hubs connection string.
Implementations
sourceimpl<'a> EventHubsConnectionStringProperties<'a>
impl<'a> EventHubsConnectionStringProperties<'a>
sourcepub fn fully_qualified_namespace(&self) -> Option<&str>
pub fn fully_qualified_namespace(&self) -> Option<&str>
The fully qualified Event Hubs namespace that the consumer is associated with. This is
likely to be similar to "{yournamespace}.servicebus.windows.net".
sourcepub fn endpoint(&self) -> Option<&Url>
pub fn endpoint(&self) -> Option<&Url>
The endpoint to be used for connecting to the Event Hubs namespace.
sourcepub fn event_hub_name(&self) -> Option<&str>
pub fn event_hub_name(&self) -> Option<&str>
The name of the specific Event Hubs entity instance under the associated Event Hubs namespace.
The name of the shared access key, either for the Event Hubs namespace or the Event Hubs entity.
The value of the shared access key, either for the Event Hubs namespace or the Event Hubs entity.
The value of the fully-formed shared access signature, either for the Event Hubs namespace or the Event Hubs entity.
sourcepub fn to_connection_string(&self) -> Result<String, ToConnectionStringError>
pub fn to_connection_string(&self) -> Result<String, ToConnectionStringError>
Creates an Event Hubs connection string based on this set of
EventHubsConnectionStringProperties.
sourcepub fn parse(connection_string: &'a str) -> Result<Self, FormatError>
pub fn parse(connection_string: &'a str) -> Result<Self, FormatError>
Parses the specified Event Hubs connection string into its component properties.