pub struct EventHubsRetryOptions {
    pub max_retries: MaxRetries,
    pub delay: Duration,
    pub maximum_delay: Duration,
    pub try_timeout: Duration,
    pub mode: EventHubsRetryMode,
}
The set of options that can be specified to influence how retry attempts are made, and a failure is eligible to be retried.

Fields

max_retries: MaxRetries

The maximum number of retry attempts before considering the associated operation to have failed

delay: Duration

The delay or back-off factor to apply between retry attempts

maximum_delay: Duration

The maximum delay to allow between retry attempts

try_timeout: Duration

The maximum duration to wait for an operation, per attempt

mode: EventHubsRetryMode

The approach to use for calculating retry delays

The default retry mode is EventHubsRetryMode::Exponential