Struct azeventhubs::EventData
source · pub struct EventData { /* private fields */ }Expand description
An Event Hubs event, encapsulating a set of data and its associated metadata.
Implementations
sourceimpl EventData
impl EventData
sourcepub fn content_type(&self) -> Option<&str>
pub fn content_type(&self) -> Option<&str>
The content type associated with the event
sourcepub fn set_content_type(&mut self, content_type: impl Into<Option<String>>)
pub fn set_content_type(&mut self, content_type: impl Into<Option<String>>)
Sets the content type associated with the event
sourcepub fn message_id(&self) -> Option<Cow<'_, str>>
pub fn message_id(&self) -> Option<Cow<'_, str>>
An application-defined value that uniquely identifies the event. The identifier is a free-form value and can reflect a GUID or an identifier derived from the application context.
sourcepub fn set_message_id(
&mut self,
message_id: impl Into<String>
) -> Result<(), SetMessageIdError>
pub fn set_message_id( &mut self, message_id: impl Into<String> ) -> Result<(), SetMessageIdError>
Sets the message ID associated with the event
sourcepub fn correlation_id(&self) -> Option<Cow<'_, str>>
pub fn correlation_id(&self) -> Option<Cow<'_, str>>
An application-defined value that represents the context to use for correlation across one or more operations. The identifier is a free-form value and may reflect a unique identity or a shared data element with significance to the application.
sourcepub fn set_correlation_id(&mut self, correlation_id: impl Into<Option<String>>)
pub fn set_correlation_id(&mut self, correlation_id: impl Into<Option<String>>)
Sets the correlation ID associated with the event
sourcepub fn properties(&self) -> Option<&OrderedMap<String, SimpleValue>>
pub fn properties(&self) -> Option<&OrderedMap<String, SimpleValue>>
The set of free-form properties which may be used for associating metadata with the event that is meaningful within the application context.