Struct azeventhubs::EventHubsRetryOptions
source · pub struct EventHubsRetryOptions {
pub max_retries: MaxRetries,
pub delay: Duration,
pub maximum_delay: Duration,
pub try_timeout: Duration,
pub mode: EventHubsRetryMode,
}Expand description
The set of options that can be specified to influence how retry attempts are made, and a failure is eligible to be retried.
Fields
max_retries: MaxRetriesThe maximum number of retry attempts before considering the associated operation to have failed
delay: DurationThe delay or back-off factor to apply between retry attempts
maximum_delay: DurationThe maximum delay to allow between retry attempts
try_timeout: DurationThe maximum duration to wait for an operation, per attempt
mode: EventHubsRetryModeThe approach to use for calculating retry delays
The default retry mode is EventHubsRetryMode::Exponential